@@ -8,7 +8,7 @@ use Encode;
 use File::Spec;
 use YAML::Tiny ();
 
-use version 0.77; our $VERSION = version->declare("v0.9.5");
+use version 0.77; our $VERSION = version->declare("v0.9.6");
 
 __PACKAGE__->setting(
     handle_static => 1,
@@ -93,6 +93,61 @@ get '/atom.xml' => sub {
     $c->create_response(200, ['Content-Type' => 'application/atom+xml'], [encode($c->encoding, $xml)]);
 };
 
+sub get_functions {
+    my $self = shift;
+
+    state %functions;
+    my $functionspl = File::Spec->catfile($self->base_dir, 'share', 'functions.pl');
+    if (-f -r $functionspl && !%functions) {
+        my $code = do {
+            local $/;
+            open my $fh, '<', $functionspl or die $!;
+            <$fh>
+        };
+        my $package = 'Riji::_Sandbox::Functions';
+        eval <<"..."; ## no critic
+        package $package;
+        use strict;
+        use warnings;
+        use utf8;
+
+        $code
+        1;
+...
+        if (my $err = $@) {
+            die "$err\n";
+        }
+        require Module::Functions;
+        my @functions = Module::Functions::get_public_functions($package);
+        for my $func (@functions) {
+            $functions{$func} = $package->can($func);
+        }
+    }
+    %functions;
+}
+
+sub create_view {
+    my $self = shift;
+
+    Text::Xslate->new(
+        path => $self->template_dir,
+        module   => [
+            'Text::Xslate::Bridge::Star',
+        ],
+        function => {
+            c         => sub { $self->context },
+            uri_for   => sub { $self->context->uri_for(@_) },
+            uri_with  => sub { $self->context->req->uri_with(@_) },
+            $self->get_functions,
+        },
+        ($self->debug_mode ? ( warn_handler => sub {
+            Text::Xslate->print( # print method escape html automatically
+                '[[', @_, ']]',
+            );
+        } ) : () ),
+    );
+}
+
 1;
 __END__
 
